@@ -14,7 +14,10 @@ class CsvUnitOfWork(AbstractUnitOfWork):
             writer = csv.writer(f)
             # writer.writerow(["slurm_id", "submit_time", "repo_commit_tag",
             # "sbatch_file", "status", "description"])
-            for job in self.jobs.list():
+            for job in self.jobs.list_all():
+                dependency_name = job.dependencies.type.name if job.dependencies else "none"
+                dependency_state = job.dependencies.state if job.dependencies else "none"
+                dependency_ids = job.dependencies.ids if job.dependencies else []
                 writer.writerow(
                     [
                         job.slurm_id,
@@ -23,6 +26,9 @@ class CsvUnitOfWork(AbstractUnitOfWork):
                         job.sbatch,
                         job.status,
                         job.description,
+                        dependency_name,
+                        dependency_state,
+                        dependency_ids,
                         job.deleted,
                     ]
                 )
